import commonjs from "rollup-plugin-commonjs";
import babel from "rollup-plugin-babel";
import postcss from "rollup-plugin-postcss";
import ascii from "rollup-plugin-ascii";
import resolve from "@rollup/plugin-node-resolve";
import includePaths from "rollup-plugin-includepaths";
import { terser } from "rollup-plugin-terser";

const externalAry = [
    "antd",
    "antd/es/locale/zh_CN",
    "mayihr-components",
    "antd/dist/antd.css",
    '@ant-design/icons',
    '@ant-design/pro-layout',
    "moment",
    "moment/locale/zh-cn",
    "echarts",
    "prop-types",
    "snowflake-id",
    "win-trade-base",
    "@lugia/lugiax",
    "@ant-design/icons",
    "react",
    "react-transition-group",
    "react-dnd",
    "react-router-dom",
    "history",
    "js-base64",
    "react-router",
    "react-dnd-html5-backend",
    "react-loadable",
    "react-resizable",
    "axios"
];

export default {
    input: "./src/index.js",
    output: {
        file: "dist/bundle.js",
        format: "cjs",
        sourcemap: true,
    },
    plugins: [
        resolve(),
        includePaths({
            include: { "yss-biz": "./src/index.js" },
        }),
        babel({ exclude: "**/node_modules/**", runtimeHelpers: true }),
        commonjs(),
        ascii(),
        postcss({
            //  增加 css-module 功能
            // modules: {scopeBehaviour: "global",exportGlobals: true},
            // 支持带有*.modules.css直接为css-module
            autoModules: true,
            // Extract CSS to the same location where JS file is generated but with .css extension.
            // 控制是否要将css提取出来，true的时候会在js相同的位置生成css文件，false就不会
            extract: false,
            // Use named exports alongside default export.
            namedExports: true,
            // Minimize CSS, boolean or options for cssnano.
            minimize: true,
            // Enable sourceMap.
            sourceMap: true,
            // This plugin will process files ending with these extensions and the extensions supported by custom loaders.
            extensions: [".less", ".css"],
            use: [
                ['less', {
                    javascriptEnabled: true,
                    modules: true,
                    modifyVars: {
                        "@primary-color": "#34ad37"
                    },
                }]
            ],
        }),
        ["import", { "libraryName": "antd", "libraryDirectory": "es", "style": true }],
        terser(),
    ],
    external: externalAry,
};
