import React, { useEffect, useState, useImperativeHandle } from 'react';
import style from './index.module.less';
import Button from "./Button";
import Area from "./Area";
import Input from './Input'
import Upload from './Upload'
import Radios from './Radios'
import CheckBoxes from './CheckBoxes'
import Switch from './Switch'
import Select from './Select'
import Divider from './Divider'
import Text from './Text'
import DatePicker from './DatePicker'
import Search from './Search'
import Table from './Table'
import Form from './Form'
import { dealData } from '../Util/Tool'


// Input，Form，Radios，CheckBoxes，Select，DatePicker，Table需要支持外包可以随时改变value并且完成渲染
const ComponetsRender = (props, ref) => {
    const [componetsValue, setData] = useState("")
    const [keyValue, setKey] = useState(0)
    const [formValue, setFormValue] = useState([])
    const [optionValue, setOptionValue] = useState([])
    useEffect(() => {
        setData(props.value)
        setKey(keyValue > 2000 ? 1 : keyValue + 1)
    }, [props.value])
    useImperativeHandle(ref, () => {
        return {
            setValue(e) {
                console.log(e, 'useImperativeHandle', props)
                setData(e)
                setKey(keyValue > 2000 ? 1 : keyValue + 1)
            },
            setOption(e) {
                console.log(e, 'setOption', props)
                setOptionValue(e)
            },
            getValue() {
                return componetsValue
            },
            setFormListValue(e) {
                setFormValue(e)
            }
        };
    });
    const render = () => {
        const data = dealData(props.data)
        const stylea = dealData(props.style)
        const optionS = {
            id: props.id,
            name: props.name,
            componetType: props.type,
            bind: props.bind,
            parent: props.parent,
            dispatchEvent: props.dispatchEvent,
            mode: props.mode,
            data,
            style: stylea,
            action: props.action,
            value: componetsValue
        }

        switch (props.type) {
            case 'Button':
                return <Button {...optionS}></Button>
            case 'Input':
                return <Input {...optionS} key={keyValue}></Input>
            case 'Divider':
                return <Divider {...optionS} edit={props.edit}></Divider>
            case 'Form':
                return <Form {...optionS} children={props.children} edit={props.edit} childrenItems={props.childrenItems} formValue={formValue} ></Form>
            case 'Area':
                return <Area {...optionS} children={props.children} edit={props.edit}></Area>
            case 'Search':
                return <Search {...optionS} edit={props.edit} children={props.children} childrenItems={props.childrenItems}></Search>
            case 'Text':
                return <Text {...optionS} edit={props.edit}></Text>
            case 'Upload':
                return <Upload {...optionS}></Upload>
            case 'Radios':
                return <Radios {...optionS} edit={props.edit} key={keyValue}></Radios>
            case 'Switch':
                return <Switch {...optionS} key={keyValue}></Switch>
            case 'CheckBoxes':
                return <CheckBoxes {...optionS} edit={props.edit} key={keyValue}></CheckBoxes>
            case 'Select':
                return <Select {...optionS} edit={props.edit} key={keyValue} optionValue={optionValue}></Select>
            case 'DatePicker':
                return <DatePicker {...optionS} key={keyValue}></DatePicker>
            case 'Table':
                return <Table {...optionS} children={props.children} edit={props.edit} childrenItems={props.childrenItems} ></Table>
            case 'widget':
                return <div className={style.widgetContent}>{props.name}</div>
        }
    }
    return <div className={style.mayiRender} >{render()}</div>
};

export default React.forwardRef(ComponetsRender)

