const HexToDecimal = (value) => {
  const array = [
    "0",
    "1",
    "2",
    "3",
    "4",
    "5",
    "6",
    "7",
    "8",
    "9",
    "A",
    "B",
    "C",
    "D",
    "E",
    "F",
  ];
  const numArray = value.split("");
  let num = 0;
  numArray.map((item, index) => {
    const dataIndex = array.lastIndexOf(item.toUpperCase());
    if (dataIndex !== -1) {
      num += dataIndex * Math.pow(16, numArray.length - 1 - index);
    }
  });

  return num;
};
const colorChange = (value) => {
  let colorArray = [];
  if (value.length === 3) {
    const temp = value.split("");
    temp.map((item) => {
      const colorNum = item.toString() + item.toString();
      colorArray.push(HexToDecimal(colorNum));
    });
  }
  if (value.length == 6) {
    const temp = value.split("");
    for (let i = 0; i < 3; i++) {
      const colorNum = temp[2 * i].toString() + temp[2 * i + 1].toString();
      colorArray.push(HexToDecimal(colorNum));
    }
  }
  return colorArray;
};

function debounce(func, wait, immediate) {
  let timeout, args, context, timestamp, result;
  if (null == wait) wait = 800;

  function later() {
    let last = Date.now() - timestamp;

    if (last < wait && last >= 0) {
      timeout = setTimeout(later, wait - last);
    } else {
      timeout = null;
      if (!immediate) {
        result = func.apply(context, args);
        context = args = null;
      }
    }
  }

  let debounced = function () {
    context = this;
    args = arguments;
    timestamp = Date.now();
    let callNow = immediate && !timeout;
    if (!timeout) timeout = setTimeout(later, wait);
    if (callNow) {
      result = func.apply(context, args);
      context = args = null;
    }

    return result;
  };

  debounced.clear = function () {
    if (timeout) {
      clearTimeout(timeout);
      timeout = null;
    }
  };

  debounced.flush = function () {
    if (timeout) {
      result = func.apply(context, args);
      context = args = null;

      clearTimeout(timeout);
      timeout = null;
    }
  };

  return debounced;
}

const regData = (regKey, value) => {
  let reg;
  switch (regKey) {
    case "email":
      reg = /^([A-Za-z0-9_\-\.])+\@([A-Za-z0-9_\-\.])+\.([A-Za-z]{2,4})$/;
      break;
    case "mobile":
      reg = /^1[23456789]\d{9}$/;
      break;
    case "webUrl":
      reg =
        /^((https?|ftp|file|http):\/\/)?([\da-z\.-]+)\.([a-z\.]{2,6})([\/\w \.-]*)*\/?$/;
      break;
    case "domian":
      reg =
        /[a-zA-Z0-9][-a-zA-Z0-9]{0,62}(\.[a-zA-Z0-9][-a-zA-Z0-9]{0,62})+\.?/;
      break;
    case "postalCode":
      reg = /^[1-9]\d{5}(?!\d)$/g;
      break;
  }
  if (regKey === 'notNull') {
    return value ? true : false
  }
  if (regKey !== "number") {
    return reg.test(value);
  } else {
    if (typeof value === "number" || typeof value === "string") {
      return !isNaN(value * 1);
    }
    return false;
  }
};
const parseWidget = (data) => {
  if (data.tabList.length === 0) {
    data.tabList[0] = { name: '', childrenItems: [] }
    for (let i in data.content) {
      const sort = data.content[i].sort
      const parent = data.content[i].parent
      if (parent === 'root') {
        data.tabList[0].childrenItems[sort] = data.content[i]
      } else {
        data.content[parent].childrenItems[sort] = data.content[i]
      }
    }
  } else {
    for (let i in data.content) {
      const sort = data.content[i].sort
      const parent = data.content[i].parent
      if (parent === 'root') {
        const tabkey = data.content[i].tabId
        data.tabList.map((item) => {
          item.childrenItems = item.childrenItems ? item.childrenItems : []
          if (item.key === tabkey) {
            item.childrenItems[sort] = data.content[i]
          }
        })
      } else {
        data.content[parent].childrenItems[sort] = data.content[i]
      }
    }
  }
}
const dealData = (value) => {
  const returnD = {}
  value && value.map(item => {
    returnD[item.code] = { ...item }
  })
  return returnD
}
const getAllCode = (data) => {
  let componetCode = []
  let interfaceCode = []
  let dictCode = []
  for (let i in data) {
    if (data[i].type === "widget") {
      componetCode.push(data[i].code)
    }
    const dataNow = dealData(data[i].data)
    if (dataNow.initData && dataNow.initData.value) {
      interfaceCode.push(dataNow.initData.value)
    }
    if (dataNow.group && dataNow.group.value) {
      dictCode.push(dataNow.group.value)
    }
    if (dataNow.submitUrl && dataNow.submitUrl.value) {
      interfaceCode.push(dataNow.submitUrl.value)
    }
    if (dataNow.customColumn && dataNow.customColumn.value) { interfaceCode.push(dataNow.customColumn.value) }
  }
  return { componetCode: Array.from(new Set(componetCode)), interfaceCode: Array.from(new Set(interfaceCode)), dictCode: Array.from(new Set(dictCode)) }
}
const getRealUrl = (url, data) => {
  let realUrl = url.match(/(\$\{[a-zA-z]{1,}\}){1,}/g)
  let orginUrl = url
  console.log(realUrl,data)
  if (realUrl) {
    realUrl.map(item => {
      console.log(item.match(/[a-zA-z]{1,}/g))
      orginUrl = orginUrl.replace(item, data[item.match(/[a-zA-z]{1,}/g)[0]])
    })
  }
  return orginUrl
}
export { colorChange, regData, debounce, parseWidget, getAllCode, dealData, getRealUrl };
